
# =========================================================================
# Exemple de construction de la reprsentation triangulaire de trois sries
# de somme normalise (parfois appele "endowment triangle")
# =========================================================================

# Le fichier "triangle.txt" contient des donnes fictives reprsentant
# la ventilation en trois secteurs (alimentation, habillement et "autre")
# du CA de six magasins; les donnes sont brutes, cad en niveau dans une
# unit montaire convenable, et sont donc d'abord converties en ratios.
# Pour la commodit de la construction du graphique, on a ajout trois
# lignes ou magasins artificiels, n'ayant qu'un seul secteur et qui donneront
# les sommets du triangle. 

maga = read.table("triangle.txt", h=T) # la colonne "Magasin" est
# l'identifiant (entre guillemets dans le fichier triangle.txt)

maga # pour voir

attach(maga) # pour pouvoir appeler les variables par leur nom

# normalisation par magasin
total=Alim+Habi+Autre 
Alim=Alim/total
Habi=Habi/total
Autre=Autre/total

# graphique xy "traditionnel", par exemple Alim x Habi
plot(Alim, Habi, xlim=c(-0.1, 1.1), ylim=c(0, 1.1)) 
text(Alim, Habi, labels=Magasin, pos="3")

# passage des coordonnes "barycentriques" dans le triangle quilatral
# "unitaire" Alimentation-Habillement-Autre de sommets (0,0), (1,0) et
# (racine(3)/2,1) aux coordonnes "cartsiennes" selon les formules du cours

x=(Habi+Autre/2)
y=(Autre*(3^0.5)/2)

# coordonnes des sommets pour le trac du triangle, le premier rpt
# au bout pour refermer la ligne

tx=c(0, 1, 0.5, 0)
ty=c(0, 0, (3^0.5)/2, 0)

# pour figurer galement les mdianes, on peut utiliser la squence
# suivante  la place de celle qui prcde

# k=(3^0.5)/2 # pour se simplifier la vie...
# tx=c(0, 1, 0.5, 0, 0.75, 1, 0.25, 0.5, 0.5)
# ty=c(0, 0, k, 0, k/2, 0, k/2, k, 0)

# graphique triangulaire
plot(x, y, main="Alimentation-Habillement-Autre", xlab="", ylab="", xlim=c(-0.1, 1.1), ylim=c(-0.025, 0.95))
text(x, y, labels=Magasin, pos="3") # intituls dans le graphique, sommets compris
points(tx, ty, type='l') # trac du triangle
